@@ -12,7 +12,7 @@ import base64, PIL, urllib
 import shutil
 import urllib.request as urllib2
 import pythoncom
-from installerapp.uitilities import checkname
+from installerapp import checkname
 
 installed = False
 
